<script setup>
import { ref } from 'vue';
import { Inertia } from '@inertiajs/inertia';
import { Head, Link } from '@inertiajs/inertia-vue3';
import JetApplicationMark from '@/Jetstream/ApplicationMark.vue';
import JetBanner from '@/Jetstream/Banner.vue';
import JetDropdown from '@/Jetstream/Dropdown.vue';
import JetDropdownLink from '@/Jetstream/DropdownLink.vue';
import JetNavLink from '@/Jetstream/NavLink.vue';
import JetResponsiveNavLink from '@/Jetstream/ResponsiveNavLink.vue';
import Highcharts from 'highcharts';
import DK_Alert from '@/components/dk_Alert.vue';


defineProps({
    title: String,
});

const showingNavigationDropdown = ref(false);

const switchToTeam = (team) => {
    Inertia.put(route('current-team.update'), {
        team_id: team.id,
    }, {
        preserveState: false,
    });
};

const logout = () => {
    Inertia.post(route('logout'));
};



</script>

<style>

</style>



<template>

    <DK_Alert :visibility="ComponentVisibility" @close="hideComponent" :title="ComponentTitle" :message="ComponentMessage" :width="ComponentWidth"></DK_Alert>

    <div>

        <Head :title="title" />

        <JetBanner />
        <loader-component></loader-component>
        <div style="min-height: 100vh !important">
            <nav class="border-0 bg-blue-navbar sticky drop-shadow-xl top-0 z-[110]">
                <!-- Primary Navigation Menu -->
                <div class="w-auto lg:px-6 px-4">
                    <div class="flex justify-between h-12">
                        <div class="flex">
                            <Link class="h-9 self-center mr-5 max-w-[6.5rem] lg:mr-6">
                            <JetApplicationMark />
                            </Link>
                        </div>

                        <div class="flex items-center ml-6">

                            <!-- Settings Dropdown -->
                            <div class="ml-3 relative">
                                <JetDropdown align="right">
                                    <template #trigger>

                                    </template>

                                    <template #content>
                                        <div class="m-0 p-0 lg:hidden">

                                            <div class="my-0.5 mx-2 border-t border-white"></div>
                                        </div>



                                        <!-- Account Management -->

                                        <JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('profile.show')">
                                            My Profile
                                        </JetDropdownLink>

                                        <JetDropdownLink class="text-white-snow hidden"
                                            v-if="$page.props.jetstream.hasApiFeatures && ($page.props.user.admin == 0 || $page.props.user.admin == 1)"
                                            onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('api-tokens.index')">
                                            API Tokens
                                        </JetDropdownLink>

                                        <!-- Admin Management -->
                                        <!--<template v-if="$page.props.user.admin == 1">   
                                                <JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('manageProfiles')">
                                                    Manage Profiles
                                                </JetDropdownLink>
                                            </template>-->

                                        <!-- Authentication -->
                                        <form @submit.prevent="logout">
                                            <JetDropdownLink as="button">
                                                <div class="grid grid-cols-2">
                                                    <div> Sign Out </div>
                                                    <div class="justify-self-end">
                                                        <p class="svg-icon svg-icon-primary svg-icon-2x">
                                                            <svg xmlns="http://www.w3.org/2000/svg"
                                                                xmlns:xlink="http://www.w3.org/1999/xlink" width="20px"
                                                                height="20px" viewBox="0 0 24 24" version="1.1">
                                                                <g stroke="none" stroke-width="1" fill="none"
                                                                    fill-rule="evenodd">
                                                                    <rect x="0" y="0" width="24" height="24" />
                                                                    <path
                                                                        d="M14.0069431,7.00607258 C13.4546584,7.00607258 13.0069431,6.55855153 13.0069431,6.00650634 C13.0069431,5.45446114 13.4546584,5.00694009 14.0069431,5.00694009 L15.0069431,5.00694009 C17.2160821,5.00694009 19.0069431,6.7970243 19.0069431,9.00520507 L19.0069431,15.001735 C19.0069431,17.2099158 17.2160821,19 15.0069431,19 L3.00694311,19 C0.797804106,19 -0.993056895,17.2099158 -0.993056895,15.001735 L-0.993056895,8.99826498 C-0.993056895,6.7900842 0.797804106,5 3.00694311,5 L4.00694793,5 C4.55923268,5 5.00694793,5.44752105 5.00694793,5.99956624 C5.00694793,6.55161144 4.55923268,6.99913249 4.00694793,6.99913249 L3.00694311,6.99913249 C1.90237361,6.99913249 1.00694311,7.89417459 1.00694311,8.99826498 L1.00694311,15.001735 C1.00694311,16.1058254 1.90237361,17.0008675 3.00694311,17.0008675 L15.0069431,17.0008675 C16.1115126,17.0008675 17.0069431,16.1058254 17.0069431,15.001735 L17.0069431,9.00520507 C17.0069431,7.90111468 16.1115126,7.00607258 15.0069431,7.00607258 L14.0069431,7.00607258 Z"
                                                                        fill="#FFFAFA" fill-rule="nonzero"
                                                                        transform="translate(9.006943, 12.000000) scale(-1, 1) rotate(-90.000000) translate(-9.006943, -12.000000) " />
                                                                    <rect fill="#FFFAFA"
                                                                        transform="translate(14.000000, 12.000000) rotate(-270.000000) translate(-14.000000, -12.000000) "
                                                                        x="13" y="6" width="2" height="12" rx="1" />
                                                                    <path
                                                                        d="M21.7928932,9.79289322 C22.1834175,9.40236893 22.8165825,9.40236893 23.2071068,9.79289322 C23.5976311,10.1834175 23.5976311,10.8165825 23.2071068,11.2071068 L20.2071068,14.2071068 C19.8165825,14.5976311 19.1834175,14.5976311 18.7928932,14.2071068 L15.7928932,11.2071068 C15.4023689,10.8165825 15.4023689,10.1834175 15.7928932,9.79289322 C16.1834175,9.40236893 16.8165825,9.40236893 17.2071068,9.79289322 L19.5,12.0857864 L21.7928932,9.79289322 Z"
                                                                        fill="#FFFAFA" fill-rule="nonzero"
                                                                        transform="translate(19.500000, 12.000000) rotate(-90.000000) translate(-19.500000, -12.000000) " />
                                                                </g>
                                                            </svg>
                                                        </p>
                                                    </div>
                                                </div>
                                            </JetDropdownLink>
                                        </form>
                                    </template>
                                </JetDropdown>
                            </div>
                        </div>
                    </div>
                </div>
            </nav>
            <!-- Page Content -->
            <main style="min-height: calc(100vh - 4.75rem);">
                <slot />
            </main>

            <!-- Footer -->
        <nav class="relative bottom-0	bg-blue-navbar flex text-white-snow z-[110] justify-start h-7 drop-shadow-xl-footer">
            <button id="footerbtn" type="button"
                class="inline-flex items-center ml-3 sm:ml-4 md:ml-5 lg:ml-6 border-transparent text-xs leading-4 font-semibold text-white-snow">
                {{new Date().getFullYear()}} @ Datakorum Solutions S.L.
            </button>
        </nav>
    </div>
</div>
</template>

<script>
export default {

    data() {
        return {
            ComponentVisibility: false,
            ComponentTitle: '',
            ComponentMessage: '',
            ComponentWidth: '',
        }
    },

    beforeMount(){

        window.emitter.on('AppLayout_alert', (status, title, message, width) => {
            this.ComponentVisibility = status;
            this.ComponentTitle = title;
            this.ComponentMessage = message;
            this.ComponentWidth = width;
        })
    },

    mounted(){
    },

    methods: {
        showComponent() {
            this.ComponentVisibility = true; // Mostrar el componente hijo
        },

        hideComponent() {
            this.ComponentVisibility = false; // Ocultar el componente hijo cuando se emite el evento 'close'
        },
    }

}
</script>


